@@ -60,18 +60,18 @@ impl TailwindInstruction {
             ["z", rest @ ..] => TailWindZIndex::parse(rest, arbitrary, self.negative)?.boxed(),
             // Flexbox & Grid
             ["basis", rest @ ..] => TailwindBasis::parse(rest, arbitrary)?.boxed(),
-            ["flex", rest @ ..] => flex_adaptor(rest, arbitrary)?,
+            ["flex", rest @ ..] => TailwindFlex::adapt(rest, arbitrary)?,
             ["grow", rest @ ..] => TailWindGrow::parse(rest, arbitrary)?.boxed(),
             ["shrink", rest @ ..] => TailWindShrink::parse(rest, arbitrary)?.boxed(),
             ["order", rest @ ..] => TailWindOrder::parse(rest, arbitrary, self.negative)?.boxed(),
-            ["grid", rest @ ..] => TailwindGrid::parse(rest, arbitrary)?,
+            ["grid", rest @ ..] => TailwindGrid::adapt(rest, arbitrary)?,
             // https://tailwindcss.com/docs/grid-column
             ["col", rest @ ..] => TailwindColumn::parse(rest, arbitrary)?.boxed(),
             ["row", rest @ ..] => TailwindRow::parse(rest, arbitrary)?.boxed(),
             ["auto", rest @ ..] => TailwindGridAuto::parse(rest, arbitrary)?.boxed(),
             ["gap", rest @ ..] => TailwindGap::parse(rest, arbitrary)?.boxed(),
             ["justify", rest @ ..] => Self::justify_adaptor(rest, arbitrary)?,
-            ["content", rest @ ..] => TailwindContent::parse(rest, arbitrary)?,
+            ["content", rest @ ..] => TailwindContent::adapt(rest, arbitrary)?,
             ["items", rest @ ..] => TailwindItems::parse(rest, arbitrary)?.boxed(),
             ["self", rest @ ..] => TailwindSelf::parse(rest, arbitrary)?.boxed(),
             ["place", rest @ ..] => TailwindPlace::parse(rest, arbitrary)?,
@@ -180,7 +180,7 @@ impl TailwindInstruction {
             ["pointer", "events", rest @ ..] => TailwindPointerEvents::parse(rest, arbitrary)?.boxed(),
             ["resize", rest @ ..] => TailwindResize::parse(rest, arbitrary)?.boxed(),
             ["scroll", rest @ ..] => TailwindScroll::parse(rest, arbitrary, neg)?,
-            ["snap", rest @ ..] => TailwindSnap::parse(rest, arbitrary)?,
+            ["snap", rest @ ..] => TailwindSnap::adapt(rest, arbitrary)?,
             ["touch", rest @ ..] => TailwindTorch::parse(rest, arbitrary)?.boxed(),
             ["select", rest @ ..] => TailwindSelect::parse(rest, arbitrary)?.boxed(),
             ["will", "change", rest @ ..] => TailwindWillChange::parse(rest, arbitrary)?.boxed(),
